import pytest
from orchestrator.types import SubscriptionLifecycle
from products.product_blocks.site import SiteTier

from gso.products.product_types.site import ImportedSite
from test.workflows import assert_complete, extract_state, run_workflow


@pytest.mark.workflow()
def test_create_imported_site_success(faker):
    initial_created_site_data = [
        {
            "site_name": faker.site_name(),
            "site_city": faker.city(),
            "site_country": faker.country(),
            "site_country_code": faker.country_code(),
            "site_latitude": "-74.0060",
            "site_longitude": "40.7128",
            "site_bgp_community_id": faker.pyint(),
            "site_internal_id": faker.pyint(),
            "site_tier": SiteTier.TIER1,
            "site_ts_address": faker.ipv4(),
            "partner": "GEANT",
        }
    ]
    result, _, _ = run_workflow("create_imported_site", initial_created_site_data)

    assert_complete(result)
    state = extract_state(result)
    subscription_id = state["subscription_id"]
    subscription = ImportedSite.from_subscription(subscription_id)
    assert subscription.status == SubscriptionLifecycle.ACTIVE
